pocketpose.converters.base_converter - PocketPose 0.0.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `pocketpose.converters.base_converter`

## Module Contents

### Classes

`BaseConverter` | Helper class that provides a standard way to create an ABC using

class pocketpose.converters.base_converter.BaseConverter(overwrite=True, log_level=logging.INFO)

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  __call__(model, save_path, *args, **kwargs)
  _check_overwrite(save_path)
  abstract _convert(model, save_path, *args, **kwargs)

    Convert the model to the target format and save it to the given path.

    Args:

      model (Any): The model to convert. save_path (str): Where to save the converted model. *args: Variable length argument list for the model. **kwargs: Arbitrary keyword arguments for the model.

    Returns:

      Any: The converted model.

    Raises:

      NotImplementedError: If the subclass does not implement this method.